==> nextcloud-app-tasks-0.14.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/fi.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Tulevat tehtävät",
    "Important" : "Tärkeä",
    "Today" : "Tänään",
    "Week" : "Viikko",
    "All" : "Kaikki",
    "Current" : "Nykyinen",
    "Completed" : "Valmiina",
    "Tasks" : "Tehtävät",
    "The Tasks app for Nextcloud" : "Tehtäväsovellus Nextcloudille",
    "Default list" : "Oletusluettelo",
    "Visibility of Smart Collections" : "Älykkäiden kokoelmien näkyvyys",
    "Hidden" : "Piilotettu",
    "Visible" : "Näkyvissä",
    "Automatic" : "Automaattinen",
    "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
    "No users or groups" : "Ei käyttäjiä tai ryhmiä",
    "Can edit" : "Voi muokata",
    "Unshare with {displayName}" : "Poista jako kohteesta {displayName}",
    "Unable to delete the share." : "Jakoa ei voitu poistaa.",
    "Unable to change permissions." : "Käyttöoikeuksia ei voitu muuttaa.",
    "Edit" : "Muokkaa",
    "Copy private link" : "Kopioi yksityinen linkki",
    "Copied" : "Kopioitu",
    "Cannot copy" : "Ei voida kopioida",
    "Export" : "Vie",
    "Delete" : "Poista",
    "Unshare" : "Lopeta jakaminen",
    "Save" : "Tallenna",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Tämä poistaa kalenterin \"{calendar}\" ja kaikki vastaavat tapahtumat ja tehtävät.",
    "This will unshare the calendar \"{calendar}\"." : "Tämä lopettaa kalenterin \"{calendar}\" jakamisen.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Tämä poistaa luettelon \"{list}\" ja kaikki vastaavat tehtävät.",
    "Calendar link copied to clipboard." : "Kalenterilinkki kopioitu leikepöydälle.",
    "Calendar link could not be copied to clipboard." : "Kalenterilinkkiä ei voitu kopioida leikepöydälle.",
    "The name \"{calendar}\" is already used." : "Nimi \"{calendar}\" on jo käytössä.",
    "An empty name is not allowed." : "Nimi ei voi olla tyhjä.",
    "An error occurred, unable to delete the calendar." : "Tapahtui virhe, kalenteria ei voitu poistaa.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Poistetaan kalenteri {countdown} sekunnissa","Poistetaan kalenteri {countdown} sekunnissa"],
    "Trash bin" : "Roskakori",
    "Loading deleted calendars, tasks and events." : "Ladataan poistettuja kalentereita, tehtäviä ja tapahtumia.",
    "You do not have any deleted calendars, tasks or events." : "Sinulla ei ole poistettuja kalentereita, tehtäviä tai tapahtumia.",
    "Name" : "Nimi",
    "Deleted" : "Poistettu",
    "Restore" : "Palauta",
    "Delete permanently" : "Poista pysyvästi",
    "Empty trash bin" : "Tyhjennä roskakori",
    "Untitled task" : "Nimetön tehtävä",
    "Untitled event" : "Nimetön tapahtuma",
    "Untitled item" : "Nimetön kohde",
    "Unknown calendar" : "Tuntematon kalenteri",
    "Could not load deleted calendars and objects" : "Ei voitu ladata poistettuja kalentereita ja objekteja",
    "Could not delete calendar or event" : "Kalenteria tai tapahtumaa ei voitu poistaa",
    "Could not restore calendar or event" : "Kalenteria tai tapahtumaa ei voi palauttaa",
    "Do you really want to empty the trash bin?" : "Haluatko varmasti tyhjentää roskakorin?",
    "Select a calendar" : "Valitse kalenteri",
    "Set date" : "Aseta päivänmäärä",
    "Set time" : "Aseta aika",
    "Delete date" : "Poista päivänmäärä",
    "Set value" : "Aseta arvo",
    "Delete value" : "Poista arvo",
    "Delete all completed tasks." : "Poista kaikki valmistuneet tehtävät.",
    "Delete completed tasks." : "Poista valmistuneet tehtävät.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Poista kaikki valmistuneet tehtävät kalenterista \"{calendar}\".",
    "No errors" : "Ei virheitä",
    "Open your browser console for more details" : "Avaa selaimesi konsoli nähdäksesi lisätietoja",
    "Add an important task to \"{calendar}\"…" : "Lisää tärkeä tehtävä kalenteriin \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Lisää nykyinen tehtävä kalenteriin \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Lisää tehtävä kalenteriin \"{calendar}\"…",
    "Load all completed tasks." : "Lataa kaikki valmistuneet tehtävät.",
    "Change sort order" : "Muuta järjestystä",
    "Start date" : "Aloituspäivä",
    "Due date" : "Eräpäivä",
    "Created date" : "Luontipäivämäärä",
    "Last modified" : "Viimeksi muokattu",
    "Completed date" : "Valmistumispäivämäärä",
    "Priority" : "Tärkeys",
    "Alphabetically" : "Aakkosjärjestys",
    "Manually" : "Käsin",
    "{complete} % completed" : "{complete} % valmiina",
    "Task has hidden subtasks" : "Tehtävällä on piilotettuja alitehtäviä",
    "Task is pinned" : "Tehtävä on kiinnitetty",
    "Add subtask" : "Lisää alitehtävä",
    "Show subtasks" : "Näytä alitehtävät",
    "Hide subtasks" : "Piilota alitehtävät",
    "Show closed subtasks" : "Näytä suljetut alitehtävät",
    "Hide closed subtasks" : "Piilota suljetut alitehtävät",
    "Delete task" : "Poista tehtävä",
    "[Yesterday]" : "[Eilen]",
    "[Today]" : "[Tänään]",
    "[Tomorrow]" : "[Huomenna]",
    "Add a subtask to \"{task}\"…" : "Lisää alitehtävä tehtävään \"{task}\"…",
    "Task is completed" : "Tehtävä on valmis",
    "Create a new task" : "Luo uusi tehtävä",
    "Task summary" : "Tehtävän yhteenveto",
    "Cancel" : "Peruuta",
    "Create task" : "Luo tehtävä",
    "Creating the new task…" : "Luodaan uutta tehtävää…",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" lisättiin kalenteriin \"{calendar}\"",
    "Close" : "Sulje",
    "Open task" : "Avaa tehtävä",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n valmistunut tehtävä","%n valmistunutta tehtävää"],
    "Tomorrow" : "Huomenna",
    "Add List…" : "Lisää lista…",
    "New List" : "Uusi luettelo",
    "All day" : "Koko päivä",
    "Unpin" : "Poista kiinnitys",
    "Pin" : "Kiinnitä",
    "Show in Calendar" : "Näytä Kalenterissa",
    "Edit title" : "Muokkaa otsikkoa",
    "Details" : "Tiedot",
    "Select a classification" : "Valitse luokittelu",
    "Select a status" : "Valitse tila",
    "Select tags" : "Valitse tunnisteet",
    "Notes" : "Muistiinpanot",
    "Reminders" : "Muistutukset",
    "Repeat" : "Toista",
    "When shared show full event" : "Jaettaessa näytä koko tapahtuma",
    "When shared show only busy" : "Jaettaessa näytä vain varattuna oleminen",
    "When shared hide this event" : "Jaettuna piilota tämä tapahtuma",
    "Needs action" : "Vaatii toimenpiteitä",
    "In process" : "Käsittelyssä",
    "Canceled" : "Peruttu",
    "Loading task from server." : "Ladataan tehtävää palvelimelta.",
    "Task not found!" : "Tehtävää ei löytynyt!",
    "Set start date" : "Aseta aloituspäivä",
    "Set due date" : "Aseta eräpäivä",
    "{percent} % completed" : "{percent} % valmiina",
    "No upcoming tasks" : "Ei tulevia tapahtumia",
    "No tasks today" : "Ei tehtäviä tälle päivälle",
    "Mark as done" : "Merkitse valmiiksi",
    "Successfully created the task." : "Tehtävä luotu onnistuneesti.",
    "Could not delete the task." : "Tehtävää ei voitu poistaa.",
    "Synchronizing to the server." : "Synkronoidaan palvleimelle.",
    "Task successfully saved to server." : "Tehtävä tallennettu onnistuneesti palvelimelle.",
    "Could not update the task." : "Tehtävää ei voitu päivittää.",
    "Successfully updated the task." : "Tehtävä päivitettiin onnistuneesti.",
    "Task successfully moved to new calendar." : "Tehtävä siirretty onnistuneesti uuteen kalenteriin.",
    "An error occurred" : "Tapahtui virhe",
    "Create a task" : "Luo tehtävä"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.15.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/fi.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Tulevat tehtävät",
    "Important" : "Tärkeä",
    "Today" : "Tänään",
    "Week" : "Viikko",
    "All" : "Kaikki",
    "Current" : "Nykyinen",
    "Completed" : "Valmiina",
    "Tasks" : "Tehtävät",
    "The Tasks app for Nextcloud" : "Tehtäväsovellus Nextcloudille",
    "Default list" : "Oletusluettelo",
    "Visibility of Smart Collections" : "Älykkäiden kokoelmien näkyvyys",
    "Hidden" : "Piilotettu",
    "Visible" : "Näkyvissä",
    "Automatic" : "Automaattinen",
    "Tasks settings" : "Tehtävien asetukset",
    "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
    "No users or groups" : "Ei käyttäjiä tai ryhmiä",
    "Can edit" : "Voi muokata",
    "Unshare with {displayName}" : "Poista jako kohteesta {displayName}",
    "Unable to delete the share." : "Jakoa ei voitu poistaa.",
    "Unable to change permissions." : "Käyttöoikeuksia ei voitu muuttaa.",
    "Edit" : "Muokkaa",
    "Copy private link" : "Kopioi yksityinen linkki",
    "Copied" : "Kopioitu",
    "Cannot copy" : "Ei voida kopioida",
    "Export" : "Vie",
    "Delete" : "Poista",
    "Unshare" : "Lopeta jakaminen",
    "List name" : "Listan nimi",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Tämä poistaa kalenterin \"{calendar}\" ja kaikki vastaavat tapahtumat ja tehtävät.",
    "This will unshare the calendar \"{calendar}\"." : "Tämä lopettaa kalenterin \"{calendar}\" jakamisen.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Tämä poistaa luettelon \"{list}\" ja kaikki vastaavat tehtävät.",
    "Share this calendar" : "Jaa tämä kalenteri",
    "Share this list" : "Jaa tämä lista",
    "Calendar link copied to clipboard." : "Kalenterilinkki kopioitu leikepöydälle.",
    "List link copied to clipboard." : "Listan linkki kopioitu leikepöydälle.",
    "Calendar link could not be copied to clipboard." : "Kalenterilinkkiä ei voitu kopioida leikepöydälle.",
    "List link could not be copied to clipboard." : "Listan linkkiä ei voitu kopioida leikepöydälle.",
    "The name \"{calendar}\" is already used." : "Nimi \"{calendar}\" on jo käytössä.",
    "An empty name is not allowed." : "Nimi ei voi olla tyhjä.",
    "An error occurred, unable to delete the calendar." : "Tapahtui virhe, kalenteria ei voitu poistaa.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Poistetaan kalenteri {countdown} sekunnissa","Poistetaan kalenteri {countdown} sekunnissa"],
    "Trash bin" : "Roskakori",
    "Loading deleted calendars, tasks and events." : "Ladataan poistettuja kalentereita, tehtäviä ja tapahtumia.",
    "You do not have any deleted calendars, tasks or events." : "Sinulla ei ole poistettuja kalentereita, tehtäviä tai tapahtumia.",
    "Name" : "Nimi",
    "Deleted" : "Poistettu",
    "Restore" : "Palauta",
    "Delete permanently" : "Poista pysyvästi",
    "Empty trash bin" : "Tyhjennä roskakori",
    "Untitled task" : "Nimetön tehtävä",
    "Untitled event" : "Nimetön tapahtuma",
    "Untitled item" : "Nimetön kohde",
    "Unknown calendar" : "Tuntematon kalenteri",
    "Could not load deleted calendars and objects" : "Ei voitu ladata poistettuja kalentereita ja objekteja",
    "Could not delete calendar or event" : "Kalenteria tai tapahtumaa ei voitu poistaa",
    "Could not restore calendar or event" : "Kalenteria tai tapahtumaa ei voi palauttaa",
    "Do you really want to empty the trash bin?" : "Haluatko varmasti tyhjentää roskakorin?",
    "Select a calendar" : "Valitse kalenteri",
    "Set date" : "Aseta päivänmäärä",
    "Set time" : "Aseta aika",
    "Delete date" : "Poista päivänmäärä",
    "Set value" : "Aseta arvo",
    "Delete value" : "Poista arvo",
    "Delete all completed tasks." : "Poista kaikki valmistuneet tehtävät.",
    "Delete completed tasks." : "Poista valmistuneet tehtävät.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Poista kaikki valmistuneet tehtävät kalenterista \"{calendar}\".",
    "No errors" : "Ei virheitä",
    "Open your browser console for more details" : "Avaa selaimesi konsoli nähdäksesi lisätietoja",
    "Add an important task to \"{calendar}\"…" : "Lisää tärkeä tehtävä kalenteriin \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Lisää nykyinen tehtävä kalenteriin \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Lisää tehtävä kalenteriin \"{calendar}\"…",
    "Change sort order" : "Muuta järjestystä",
    "Start date" : "Aloituspäivä",
    "Due date" : "Eräpäivä",
    "Created date" : "Luontipäivämäärä",
    "Last modified" : "Viimeksi muokattu",
    "Completed date" : "Valmistumispäivämäärä",
    "Priority" : "Tärkeys",
    "Alphabetically" : "Aakkosjärjestys",
    "Manually" : "Käsin",
    "{complete} % completed" : "{complete} % valmiina",
    "Task has hidden subtasks" : "Tehtävällä on piilotettuja alitehtäviä",
    "Task is pinned" : "Tehtävä on kiinnitetty",
    "Add subtask" : "Lisää alitehtävä",
    "Show subtasks" : "Näytä alitehtävät",
    "Hide subtasks" : "Piilota alitehtävät",
    "Show closed subtasks" : "Näytä suljetut alitehtävät",
    "Hide closed subtasks" : "Piilota suljetut alitehtävät",
    "Delete task" : "Poista tehtävä",
    "[Yesterday]" : "[Eilen]",
    "[Today]" : "[Tänään]",
    "[Tomorrow]" : "[Huomenna]",
    "Add a subtask to \"{task}\"…" : "Lisää alitehtävä tehtävään \"{task}\"…",
    "Task is cancelled" : "Tehtävä on peruttu",
    "Task is completed" : "Tehtävä on valmis",
    "Task is read-only" : "Tehtävä on vain luku -muotoa",
    "Task is not completed" : "Tehtävää ei ole suoritettu",
    "Create a new task" : "Luo uusi tehtävä",
    "Task summary" : "Tehtävän yhteenveto",
    "Cancel" : "Peruuta",
    "Create task" : "Luo tehtävä",
    "Creating the new task…" : "Luodaan uutta tehtävää…",
    "Close" : "Sulje",
    "Open task" : "Avaa tehtävä",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" lisättiin kalenteriin \"{calendar}\"",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n valmistunut tehtävä","%n valmistunutta tehtävää"],
    "Tomorrow" : "Huomenna",
    "Add List…" : "Lisää lista…",
    "All day" : "Koko päivä",
    "Unpin" : "Poista kiinnitys",
    "Pin" : "Kiinnitä",
    "Show in Calendar" : "Näytä Kalenterissa",
    "Edit title" : "Muokkaa otsikkoa",
    "Details" : "Tiedot",
    "Select a classification" : "Valitse luokittelu",
    "Select a status" : "Valitse tila",
    "Select tags" : "Valitse tunnisteet",
    "Notes" : "Muistiinpanot",
    "Reminders" : "Muistutukset",
    "Repeat" : "Toista",
    "When shared show full event" : "Jaettaessa näytä koko tapahtuma",
    "When shared show only busy" : "Jaettaessa näytä vain varattuna oleminen",
    "When shared hide this event" : "Jaettuna piilota tämä tapahtuma",
    "Needs action" : "Vaatii toimenpiteitä",
    "In process" : "Käsittelyssä",
    "Canceled" : "Peruttu",
    "Loading task from server." : "Ladataan tehtävää palvelimelta.",
    "Task not found!" : "Tehtävää ei löytynyt!",
    "Set start date" : "Aseta aloituspäivä",
    "Set due date" : "Aseta eräpäivä",
    "{percent} % completed" : "{percent} % valmiina",
    "No upcoming tasks" : "Ei tulevia tapahtumia",
    "upcoming tasks" : "tulevaa tehtävää",
    "No tasks today" : "Ei tehtäviä tälle päivälle",
    "Mark as done" : "Merkitse valmiiksi",
    "Successfully created the task." : "Tehtävä luotu onnistuneesti.",
    "Could not delete the task." : "Tehtävää ei voitu poistaa.",
    "Synchronizing to the server." : "Synkronoidaan palvleimelle.",
    "Task successfully saved to server." : "Tehtävä tallennettu onnistuneesti palvelimelle.",
    "Could not update the task." : "Tehtävää ei voitu päivittää.",
    "Successfully updated the task." : "Tehtävä päivitettiin onnistuneesti.",
    "Task successfully moved to new calendar." : "Tehtävä siirretty onnistuneesti uuteen kalenteriin.",
    "An error occurred" : "Tapahtui virhe",
    "Create a task" : "Luo tehtävä"
},
"nplurals=2; plural=(n != 1);");
